@@ -3,16 +3,17 @@ from .decidir_sdk.DecidirSDK import DecidirSDK
 
 
 class SDK:
-    def __init__(self, merchant:dict,processor:str=None):
+    def __init__(self, merchant: dict, processor: str = None):
         # Si se le indica el procesador
-        self.processor = None
+        self.processor = processor
         if processor == 'mercadopago':
             self._sdk = MercadoPagoSDK(merchant)
-            self.processor = 'mercadopago'
+            return
+        elif processor == 'mp_marketplace':
+            self._sdk = MercadoPagoSDK(merchant, marketplace=True)
             return
         elif processor == 'decidir':
             self._sdk = DecidirSDK(merchant)
-            self.processor = 'decidir'
             return
         # Si no utiliza el preferrred_processor que tenga el merchant
         if 'credentials' in merchant and merchant['credentials']['preferred_processor'] == 'decidir':
