@@ -23,10 +23,9 @@ class Payment:
                 'email': payment_data['payer']['email']
             },
             'site_transaction_id': str(uuid4()),  # Debe ser unico? Unico por cliente o por merchant?
-            # 'site_id': 28464385, # opcional
             'token': payment_data['token'],
             'payment_method_id': 1,    # Peso Argentino
-            'bin': '450799',    # ?
+            'bin': payment_data['bin'],    # primeros 6 digitos de la tarjeta
             # se multiplica por 100; no acepta decimales.
             'amount': round(payment_data['transaction_amount'], 2) * 100,
             'currency': 'ARS',
